==> haskell-hastache-0.6.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hastache.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hastache
version: 0.6.1
id: hastache-0.6.1-1MLAr6nLnVQ1dOgZDJbhHK
key: hastache-0.6.1-1MLAr6nLnVQ1dOgZDJbhHK
license: BSD3
copyright: Sergey S Lymar (c) 2011-2014
maintainer: Daniil Frumin <dan at covariant.me>
stability: experimental
homepage: http://github.com/lymar/hastache
synopsis: Haskell implementation of Mustache templates
description:
    Haskell implementation of Mustache templates (<http://mustache.github.com/>).
    .
    See homepage for examples of usage: <http://github.com/lymar/hastache>
category: Text
author: Sergey S Lymar <sergey.lymar@gmail.com>
exposed: True
exposed-modules:
    Text.Hastache Text.Hastache.Context
abi: e62caddb67e9b8d6ed48f8b4c4f9ac95
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hastache-0.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/hastache-0.6.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/hastache-0.6.1
hs-libraries: HShastache-0.6.1-1MLAr6nLnVQ1dOgZDJbhHK
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 containers-0.5.7.1 directory-1.2.6.2
    filepath-1.4.1.0 ieee754-0.7.6-3g8AyznINRc2xxG0JG9nsq
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM syb-0.6-C65vWCsht6A8uLstpQIXyj
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hastache/html/hastache.haddock
haddock-html: /usr/share/doc/haskell-hastache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hastache-0.6.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hastache.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hastache
version: 0.6.1
id: hastache-0.6.1-AnZxeJc4QP65v3cR8TBiTp
key: hastache-0.6.1-AnZxeJc4QP65v3cR8TBiTp
license: BSD3
copyright: Sergey S Lymar (c) 2011-2014
maintainer: Daniil Frumin <dan at covariant.me>
stability: experimental
homepage: http://github.com/lymar/hastache
synopsis: Haskell implementation of Mustache templates
description:
    Haskell implementation of Mustache templates (<http://mustache.github.com/>).
    .
    See homepage for examples of usage: <http://github.com/lymar/hastache>
category: Text
author: Sergey S Lymar <sergey.lymar@gmail.com>
exposed: True
exposed-modules:
    Text.Hastache Text.Hastache.Context
abi: 6f80e575b491b8421f4c13308ff7378b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hastache-0.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/hastache-0.6.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/hastache-0.6.1
hs-libraries: HShastache-0.6.1-AnZxeJc4QP65v3cR8TBiTp
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 containers-0.5.7.1 directory-1.2.6.2
    filepath-1.4.1.0 ieee754-0.7.9-GGOMObQlFhs75IwEfmeIx2
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM syb-0.6-C65vWCsht6A8uLstpQIXyj
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hastache/html/hastache.haddock
haddock-html: /usr/share/doc/haskell-hastache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
